# -*- coding:utf-8 -*-
import time
from optparse import OptionParser

import redis
import rediscluster
from .bash import Bash


class Rediscli(Bash):
    
    def get_parser(self):
        parser = OptionParser(add_help_option=False)
        parser.add_option("-h", action="store", dest="hostname", default="127.0.0.1",
                          help="Server hostname (default: 127.0.0.1).")
        parser.add_option("-p", action="store", type="int", dest="port", default=6379,
                          help="Server port (default: 6379).")
        parser.add_option("-a", action="store", dest="password", default=None,
                          help="Password to use when connecting to the server.")
        parser.add_option("-r", action="store", type="int", dest="repeat", default=1,
                          help="Execute specified command N times.")
        parser.add_option("-i", action="store", type="int", dest="interval", default=1,
                          help="When -r is used, waits <interval> seconds per command.\nIt is possible to specify sub-second times like -i 0.1.")
        parser.add_option("-n", action="store", type="int", dest="db", default=0,
                          help="Database number.")
        parser.add_option("-c", action="store_true", dest="cluster_mode", default=False,
                          help="Enable cluster mode (follow -ASK and -MOVED redirections).")
        return parser
 
    def _run(self):
        stdout = stderr = ""
        rc = 0
        conn = redis.Redis(host=self.options.hostname, port=self.options.port,
                           password=self.options.password, db=self.options.db,
                           decode_responses=True)
        if self.options.cluster_mode:
            stdout = conn.execute_command("cluster nodes")
            nodes = []
            for line in stdout.strip().split("\n"):
                host, port = line.split()[1].split(":")
                nodes.append({"host": host, "port": port})
            conn = StrictRedisCluster(startup_nodes=nodes,
                                      password=self.options.password,
                                      decode_responses=True)

        for _ in range(self.options.repeat):
            stdout = conn.execute_command(*self.args)
            time.sleep(self.options.interval)
        return stdout, stderr, rc
